==> haskell-email-validate-2.3.2.12-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.12
visibility:           public
id:                   email-validate-2.3.2.12-6kwSeVvUWPCJQq5DpzeYCz
key:                  email-validate-2.3.2.12-6kwSeVvUWPCJQq5DpzeYCz
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  07a38619ed5e1a4133bef09d1a2676be
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-8.8.2/site-local/email-validate-2.3.2.12
library-dirs:         /usr/lib/ghc-8.8.2/site-local/email-validate-2.3.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/email-validate-2.3.2.12
hs-libraries:         HSemail-validate-2.3.2.12-6kwSeVvUWPCJQq5DpzeYCz
depends:
    attoparsec-0.13.2.3-EeyhxyuKI5DE0uzyJdcxCo base-4.13.0.0
    bytestring-0.10.10.0 template-haskell-2.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.12-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.12
visibility:           public
id:                   email-validate-2.3.2.12-JDjTF4LHDBO4axXtfTmYtO
key:                  email-validate-2.3.2.12-JDjTF4LHDBO4axXtfTmYtO
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  a018e4fdbfa8c2539f950321329aad69
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-8.8.3/site-local/email-validate-2.3.2.12
library-dirs:         /usr/lib/ghc-8.8.3/site-local/email-validate-2.3.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/email-validate-2.3.2.12
hs-libraries:         HSemail-validate-2.3.2.12-JDjTF4LHDBO4axXtfTmYtO
depends:
    attoparsec-0.13.2.3-Ly3opcHExc4FDAnpaswQZX base-4.13.0.0
    bytestring-0.10.10.0 template-haskell-2.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
